@@ -3,7 +3,7 @@ package Pod::Weaver::PluginBundle::DROLSKY;
 use strict;
 use warnings;
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 
 use namespace::autoclean -also => ['_exp'];
 
@@ -81,7 +81,7 @@ sub configure {
     ? "bugs may be submitted through L<$bugtracker_web>."
     : (),
 
-    $distmeta->{resources}{x_MailingList} ? 'There is a mailing list available for users of this distribution, ' . "\nL<" . $distmeta->{resources}{x_MailingList} . '>.' : (),
+    $distmeta->{resources}{x_MailingList} ? 'There is a mailing list available for users of this distribution,' . "\nL<mailto:" . $distmeta->{resources}{x_MailingList} . '>.' : (),
 
     $distmeta->{resources}{x_IRC}
         ? 'This distribution also has an IRC channel at' . "\nL<"
@@ -231,7 +231,7 @@ Pod::Weaver::PluginBundle::DROLSKY - A plugin bundle for pod woven by DROLSKY
 
 =head1 VERSION
 
-version 0.44
+version 0.45
 
 =head1 SYNOPSIS
 
